@@ -71,14 +71,20 @@ class Random(TradingFactory):
 
     def event(self, data):
         signals = {'buy': {}, 'sell': {}}
+        recorded_state = {}
         # One shot or always buying or regularly
         for sid in data:
             luck = random.random()
+            recorded_state[sid] = {
+                'price': data[sid].price,
+                'luck': luck
+            }
             if luck >= self.buy_trigger:
                 signals['buy'][sid] = data[sid]
             elif luck <= self.sell_trigger:
                 signals['sell'][sid] = data[sid]
 
+        self.record(**recorded_state)
         return signals
 
 
@@ -112,16 +118,16 @@ class RegularRebalance(TradingFactory):
     def event(self, data):
         signals = {'buy': {}, 'sell': {}}
 
-        #get 20 days of prices for each security
+        # Get 20 days of prices for each security
         daily_returns = self.returns_transform.handle_data(data)
 
-        #circuit breaker in case transform returns none
-        #circuit breaker, only calculate every given rate
+        # Circuit breaker in case transform returns none
+        # Circuit breaker, only calculate every given rate
         if (daily_returns is None) or \
                 (self.elapsed_time.days % self.refresh_period is not 0):
             return signals
 
-        #reweight portfolio
+        # Reweight portfolio
         for sid in data:
             signals['buy'][sid] = data[sid]
 
